@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12811 2021-03-24 12:13:54Z Casey $
+# $Id: __init__.py 12833 2021-04-08 03:09:01Z Casey $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Casey $ (last)
-# $Date: 2021-03-24 20:13:54 +0800 (Wed, 24 Mar 2021) $
-# $Revision: 12811 $
+# $Date: 2021-04-08 11:09:01 +0800 (Thu, 08 Apr 2021) $
+# $Revision: 12833 $
 
 from __future__ import print_function
 
@@ -857,6 +857,8 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
             'IUNO_MEMBER_GMAIL_LOGIN_ENABLE': False,
             'IUNO_MEMBER_YAHOO_LOGIN_ENABLE': False,
             'IUNO_MEMBER_MSN_LIVE_LOGIN_ENABLE': False,
+            'IUNO_MEMBER_ACCOUNT_LOCALE_ENABLE': False,
+            'IUNO_MEMBER_ACCOUNT_TIMEZONE_ENABLE': False,
         }
 
         update(settingsDict, iunoMemberDefaults)
@@ -871,6 +873,8 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
                             settingsDict['IUNO_MEMBER_GMAIL_LOGIN_ENABLE'],
                             settingsDict['IUNO_MEMBER_MSN_LIVE_LOGIN_ENABLE'],
                             settingsDict['IUNO_MEMBER_YAHOO_LOGIN_ENABLE']
+                            settingsDict['IUNO_MEMBER_ACCOUNT_LOCALE_ENABLE'],
+                            settingsDict['IUNO_MEMBER_ACCOUNT_LOCALE_ENABLE']
                         )
         else: # IUNO_MEMBER_ENABLE = False
             if warns:
