@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12829 2021-04-03 03:09:45Z Casey $
+# $Id: __init__.py 12833 2021-04-08 03:09:01Z Casey $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Casey $ (last)
-# $Date: 2021-04-03 11:09:45 +0800 (Sat, 03 Apr 2021) $
-# $Revision: 12829 $
+# $Date: 2021-04-08 11:09:01 +0800 (Thu, 08 Apr 2021) $
+# $Revision: 12833 $
 
 import os
 import sys
@@ -49,10 +49,22 @@ def attachSettings(settingsDict, enableFacebook=False, enableGoogle=False,
         'django.contrib.sites',
     )
 
-    ADDING_MIDDLEWARE_CLASSES = (
-        'account.middleware.LocaleMiddleware',
-        'account.middleware.TimezoneMiddleware',
-    )
+    if enableLocale and not enableTimezone:
+        ADDING_MIDDLEWARE_CLASSES = (
+            'account.middleware.LocaleMiddleware',
+        )
+    elif not enableLocale and enableTimezone:
+        ADDING_MIDDLEWARE_CLASSES = (
+            'account.middleware.TimezoneMiddleware',
+        )
+    elif enableLocale and enableTimezone:
+        ADDING_MIDDLEWARE_CLASSES = (
+            'account.middleware.LocaleMiddleware',
+            'account.middleware.TimezoneMiddleware',
+        )
+    else:
+        # 皆不要
+        ADDING_MIDDLEWARE_CLASSES = ()
 
     installed = settingsDict['INSTALLED_APPS']
     keys = [k for k in installed if k.startswith('django.contrib')]
@@ -60,7 +72,7 @@ def attachSettings(settingsDict, enableFacebook=False, enableGoogle=False,
                         key=list(keys)[-1])
 
     extendMiddlewareClasses(settingsDict, ADDING_MIDDLEWARE_CLASSES,
-                            key='django.middleware.security.SecurityMiddleware')
+                            key='django.contrib.auth.middleware.AuthenticationMiddleware')
     #=========================================================================
 
     #=========================================================================
